# -*- coding: utf-8 -*-

# Copyright 2012 Canonical Ltd.
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU Lesser General Public License version 3, as 
# published by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU Lesser General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

from actions import (
    create_account,
    log_in,
    registration_mail_sent,
    site_not_recognised,
)
from utils import mail


def create_new_account(user, not_recognized=True):
    """Create a new account on Ubuntu Single Sign On.
    
    The browser must be on the Log in page.
    If the account creation succeeds, the browser will be back on the site
    that requested the log in.

    Keyword arguments:
    user -- The user object with the information for the new account.
        It must have the full_name, email and password attributes.
    not_recognized -- If True, the user will be logged in even if the site
        is not recognized, and all the user information will be made available
        to the site. Default is True.

    """
    log_in.assert_page()
    log_in.click_create_new_account()
    create_account.create_ubuntu_sso_account(user)
    confirmation_code = mail.get_verification_code_for_address(user.email)
    registration_mail_sent.confirm_email(confirmation_code)
    if not_recognized and site_not_recognised.is_site_not_recognized():
        site_not_recognised.make_all_information_available_to_website()
        site_not_recognised.yes_sign_in()


def sign_in(user=None, not_recognized=True):
    """Log in with an Ubuntu Single Sign On account.
    
    The browser must be on the Log in page.
    If the log in succeeds, the browser will be back on the site that
    requested the log in.

    Keyword arguments:
    user -- The user object with the information for the log in.
        It must have the email and password attributes.
        If its value is None, it means that the user has already started a
        session on Ubuntu Single Sign On and it's not necessary to enter the
        credentials again. Default is None.
    not_recognized -- If True, the user will be logged in even if the site
        is not recognized, and all the user information will be made available
        to the site. Default is True.

    """
    log_in.assert_page()
    log_in.log_in(user)
    if not_recognized and site_not_recognised.is_site_not_recognized():
        site_not_recognised.make_all_information_available_to_website()
        site_not_recognised.yes_sign_in()
